@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 //BibleTime includes
 #include <stdlib.h>
@@ -41,15 +50,17 @@ BT_OSISHTML::BT_OSISHTML() : sword::OSISHTMLHREF() {
 	addTokenSubstitute("divineName", "<span class=\"name\"><span class=\"divine\">");
 	addTokenSubstitute("/divineName", "</span></span>");
 
-	addTokenSubstitute("seg type=\"morph\"", "<span class=\"morphSegmentation\">");
-	addTokenSubstitute("/seg", "</span>");
+	//TODO Move that down to the real tag handling, segs without the type morph would generate incorrect markup, as the end span is always inserted
+//	addTokenSubstitute("seg type=\"morph\"", "<span class=\"morphSegmentation\">");
+//	addTokenSubstitute("/seg", "</span>");
 
-	// OSIS tables: <table> and </table> are the same in HTML
+	// OSIS tables
+	addTokenSubstitute("table", "<table>");
+	addTokenSubstitute("/table", "</table>");
 	addTokenSubstitute("row", "<tr>");
 	addTokenSubstitute("/row", "</tr>");
-
-	addTokenSubstitute("cell", "td");
-	addTokenSubstitute("/cell", "/td");
+	addTokenSubstitute("cell", "<td>");
+	addTokenSubstitute("/cell", "</td>");
 
 }
 
@@ -110,16 +121,29 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
 				}
 
 				if ((attrib = tag.getAttribute("lemma"))) {
-					const int count = tag.getAttributePartCount("lemma");
+ 					char splitChar = '|';
+					const int countSplit1 = tag.getAttributePartCount("lemma", '|');
+					const int countSplit2 = tag.getAttributePartCount("lemma", ' '); //TODO: not allowed, remove soon
+					int count = 0;
+					
+					if (countSplit1 > countSplit2) { //| split char
+						splitChar = '|'; //TODO: not allowed, remove soon
+						count = countSplit1;
+					}
+					else {
+						splitChar = ' ';
+						count = countSplit2;
+					}
+					
 					int i = (count > 1) ? 0 : -1;  // -1 for whole value cuz it's faster, but does the same thing as 0
 					attrValue = "";
 
 					do {
 						if (attrValue.length()) {
-							attrValue.append( "|" );
+							attrValue.append( '|' );
 						}
 
-						attrib = tag.getAttribute("lemma", i);
+						attrib = tag.getAttribute("lemma", i, splitChar);
 
 						if (i < 0) { // to handle our -1 condition
 							i = 0;
@@ -140,7 +164,20 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
 				}
 
 				if ((attrib = tag.getAttribute("morph"))) {
-					const int count = tag.getAttributePartCount("morph");
+					char splitChar = '|';
+					const int countSplit1 = tag.getAttributePartCount("morph", '|');
+					const int countSplit2 = tag.getAttributePartCount("morph", ' '); //TODO: not allowed, remove soon
+					int count = 0;
+					
+					if (countSplit1 > countSplit2) { //| split char
+						splitChar = '|';
+						count = countSplit1;
+					}
+					else {
+						splitChar = ' ';
+						count = countSplit2;
+					}
+
 					int i = (count > 1) ? 0 : -1;  // -1 for whole value cuz it's faster, but does the same thing as 0
 
 					attrValue = "";
@@ -150,7 +187,7 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
 							attrValue.append('|');
 						}
 
-						attrib = tag.getAttribute("morph", i);
+						attrib = tag.getAttribute("morph", i, splitChar);
 
 						if (i < 0) {
 							i = 0; // to handle our -1 condition
@@ -159,7 +196,18 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
 						val = strchr(attrib, ':');
 
 						if (val) { //the prefix gives the modulename
-							attrValue.append( !strncmp(attrib, "x-", 2) ? attrib+2 : attrib );
+							//check the prefix
+							if (!strncmp("robinson:", attrib, 9)) { //robinson
+								attrValue.append( "Robinson:" ); //work is not the same as Sword's module name
+								attrValue.append( val+1 );
+							}
+							//strongs is handled by BibleTime
+							/*else if (!strncmp("strongs", attrib, val-atrrib)) {
+								attrValue.append( !strncmp(attrib, "x-", 2) ? attrib+2 : attrib );
+							}*/
+							else {
+								attrValue.append( !strncmp(attrib, "x-", 2) ? attrib+2 : attrib );
+							}
 						}
 						else { //no prefix given
 							const bool skipFirst = ((val[0] == 'T') && ((val[1] == 'H') || (val[1] == 'H')));
@@ -194,6 +242,7 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
 				if (type == "crossReference") { //note containing cross references
 					myUserData->inCrossrefNote = true;
 					myUserData->noteType = BT_UserData::CrossReference;
+					myUserData->swordFootnote++; // cross refs count as notes, too
 
 					/*     //get the refList value of the right entry attribute
 					     AttributeList notes = myModule->getEntryAttributes()["Footnote"];
@@ -242,6 +291,7 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
 					//       buf.append(" <span class=\"alternative\">");
 					myUserData->noteType = BT_UserData::Alternative;
 					myUserData->suspendTextPassThru = true;
+					myUserData->swordFootnote++; // count as notes, too
 				}
 				else {
 					//           qWarning("found note in %s", myUserData->key->getShortText());
@@ -251,10 +301,14 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
 					buf.append(myUserData->key->getShortText());
 					buf.append('/');
 					buf.append( QString::number(myUserData->swordFootnote++).latin1() ); //inefficient
-					buf.append("\">*</span> ");
+
+					const SWBuf n = tag.getAttribute("n");
+					
+					buf.append("\">");
+					buf.append( (n.length() > 0) ? n.c_str() : "*" );
+					buf.append("</span> ");
 
 					myUserData->noteType = BT_UserData::Footnote;
-
 					myUserData->suspendTextPassThru = true;
 				}
 			}
@@ -263,7 +317,7 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
 
 				if (myUserData->noteType == BT_UserData::CrossReference) {
 					buf.append("</span> ");
-					myUserData->suspendTextPassThru = false;
+// 					myUserData->suspendTextPassThru = false;
 					myUserData->inCrossrefNote = false;
 				}
 				else if (myUserData->noteType == BT_UserData::Alternative) {
@@ -278,7 +332,6 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
 				myUserData->suspendTextPassThru = false;
 			}
 		}
-
 		// The <p> paragraph tag is handled by OSISHTMLHref
 		else if (!strcmp(tag.getName(), "reference")) { // <reference> tag
 
@@ -396,6 +449,9 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
 				else if (type == "underline") {
 					buf.append("<span class=\"underline\">");
 				}
+				else {
+					buf.append("<span>"); //don't break markup, </span> is inserted later
+				}
 			}
 			else if (tag.isEndTag()) { //all hi replacements are html spans
 				buf.append("</span>");
@@ -507,7 +563,7 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
 			if (!tag.isEndTag() && !tag.isEmpty()) {
 				const SWBuf expansion = tag.getAttribute("expansion");
 
-				buf.append("<span class=\"abbreviation\" expansion=\">");
+				buf.append("<span class=\"abbreviation\" expansion=\"");
 				buf.append(expansion);
 				buf.append("\">");
 			}
@@ -524,7 +580,44 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
 				buf.append("<br/>");
 				userData->supressAdjacentWhitespace = true;
 			}
+			else if (type == "x-p") { //e.g. occurs in the KJV2006 module
+				//buf.append("<br/>");
+				const SWBuf marker = tag.getAttribute("marker");
+				if (marker.length() > 0) {
+					buf.append(marker);
+				}
+			}
 		}
+		//seg tag
+		else if (!strcmp(tag.getName(), "seg")) {
+			if (!tag.isEndTag() && !tag.isEmpty()) {
+
+				const SWBuf type = tag.getAttribute("type");
+
+				if (type == "morph") {//line break
+					//This code is for WLC and MORPH (WHI)
+					XMLTag outTag("span");
+					outTag.setAttribute("class", "morphSegmentation");
+					const char* attrValue;
+					//Transfer the values to the span
+					//Problem: the data is in hebrew/aramaic, how to encode in HTML/BibleTime?
+					if (attrValue = tag.getAttribute("lemma")) outTag.setAttribute("lemma", attrValue);
+					if (attrValue = tag.getAttribute("morph")) outTag.setAttribute("morph", attrValue);
+					if (attrValue = tag.getAttribute("homonym")) outTag.setAttribute("homonym", attrValue);
+
+					buf.append(outTag.toString());
+					//buf.append("<span class=\"morphSegmentation\">");
+				}
+				else{
+					buf.append("<span>");
+				}
+			}
+			else { // seg end tag
+				buf.append("</span>");
+			}
+			//qWarning(QString("handled <seg> token. result: %1").arg(buf.c_str()).latin1());
+		}
+		
 		else { //all tokens handled by OSISHTMLHref will run through the filter now
 			return sword::OSISHTMLHREF::handleToken(buf, token, userData);
 		}
