@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 //BibleTime includes
 #include "cswordmoduleinfo.h"
@@ -9,6 +18,7 @@
 #include "clanguagemgr.h"
 
 #include "util/scoped_resource.h"
+#include "util/directoryutil.h"
 #include "util/cpointers.h"
 #include "frontend/cbtconfig.h"
 
@@ -20,9 +30,15 @@
 
 //Qt includes
 #include <qregexp.h>
+#include <qdir.h>
+#include <qvariant.h>
+#include <qfileinfo.h>
 
 //KDE includes
 #include <klocale.h>
+#include <kglobal.h>
+#include <kstandarddirs.h>
+#include <kconfig.h>
 
 //Sword includes
 #include <swbuf.h>
@@ -32,8 +48,26 @@
 #include <swconfig.h>
 #include <rtfhtml.h>
 
+//Lucence includes
+#include <CLucene.h>
+#include <CLucene/util/Reader.h>
+#include <CLucene/util/Misc.h>
+#include <CLucene/util/dirent.h>
+
+
+using namespace std;
+using namespace lucene::index;
+using namespace lucene::analysis;
+using namespace lucene::util;
+using namespace lucene::store;
+using namespace lucene::document;
+using namespace lucene::queryParser;
+using namespace lucene::search;
+
 using std::string;
 
+#define INDEX_VERSION "1"
+
 CSwordModuleInfo::CSwordModuleInfo(sword::SWModule * module, CSwordBackend * const usedBackend) {
 	m_module = module;
 	Q_ASSERT(module);
@@ -79,6 +113,7 @@ const bool CSwordModuleInfo::unlock(const QString & unlockKey) {
 
 	CBTConfig::setModuleEncryptionKey(name(), unlockKey);
 	backend()->setCipherKey(m_module->Name(), unlockKey.latin1());
+	//TODO: write to Sword config as well
 
 	return true;
 }
@@ -88,10 +123,12 @@ const bool CSwordModuleInfo::isLocked() {
 	//still works, but the cipherkey is stored in CBTConfig.
 	//Works because it is set in sword on program startup.
 
-	if (isEncrypted() && config(CipherKey).isEmpty()) {
+	if (isEncrypted()){
+		if (unlockKeyIsValid()) {
+			return false;
+		}
 		return true;
 	}
-
 	return false;
 }
 
@@ -107,71 +144,302 @@ const bool CSwordModuleInfo::isEncrypted() const {
 	sword::ConfigEntMap::iterator it = config.find("CipherKey");
 
 	if (it != config.end()) {
-	return true;
+		return true;
 	}
 
 	return false;
 }
 
-/** Returns true if something was found, otherwise return false. */
-const bool CSwordModuleInfo::search(const QString searchedText, const int searchOptions, sword::ListKey scope, void (*percentUpdate) (char, void *)) {
-	int searchType = 0;
-	int searchFlags = REG_ICASE;
+/** This function makes an estimate if a module was properly unlocked.
+ * It returns true if the first entry of the module (parsed as Latin1
+ * byte sequence) is not empty and contains only printable characters.
+ * If that is the case, we can safely assume that a) the module was properly
+ * unlocked and b) no buffer overflows will occur, which can happen when
+ * Sword filters process garbage text which was not properly decrypted.
+*/
+const bool CSwordModuleInfo::unlockKeyIsValid(){
 
-	//work around Swords thread insafety for Bibles and Commentaries
+	(*m_module) = sword::TOP;
+
+	// This needs to use ::fromLatin1 because if the text is still locked,
+	// a lot of garbage will show up. It will also work with properly decrypted
+	// Unicode text, because all non-ASCII Unicode chars consist of bytes >127 
+	// and therefore contain no control (nonprintable) characters, which are all <127.
+	QString test = QString::fromLatin1( m_module->getRawEntryBuf().c_str() );
+
+	if (test.isEmpty()){
+		qWarning("Unlock key of module %s is NOT valid", name().latin1());
+		return false;
+	}
+
+	for (unsigned int i = 0; i <= test.length(); i++){
+		if ( !test[i].isPrint() && !test[i].isNull() ){
+			qWarning("Unlock key of module %s is NOT valid", name().latin1());
+			return false;
+		}
+	}
+
+	qDebug("Unlock key of module %s is valid", name().latin1());
+	return true;
+}
+
+const QString CSwordModuleInfo::getGlobalBaseIndexLocation(){
+	return KGlobal::dirs()->saveLocation("data", "bibletime/indices");
+}
+
+const QString CSwordModuleInfo::getModuleBaseIndexLocation() const {
+	return getGlobalBaseIndexLocation() + QString("/") + name().ascii();
+}
+
+const QString CSwordModuleInfo::getModuleStandardIndexLocation() const { //this for now returns the location of the main index
+	 return getModuleBaseIndexLocation() + QString("/standard");
+}
+
+const bool CSwordModuleInfo::hasIndex() { //this will return true only 
+	//if the index exists and has correct version information for both index and module
+
+	QDir d;
+	if (!d.exists( getModuleStandardIndexLocation() )) {
+		return false;
+	}
+	
+	//first check if the index version and module version are ok
+	util::scoped_ptr<KConfig> indexconfig(
+		new KConfig( getModuleBaseIndexLocation() + QString("/bibletime-index.conf") )
+	);
+
+	if (hasVersion()){
+		if (indexconfig->readEntry("module-version") != QString(config(CSwordModuleInfo::ModuleVersion)) ){
+			return false;
+		}
+	}
+	if (indexconfig->readEntry("index-version") != QString( INDEX_VERSION )){
+		qDebug("%s: INDEX_VERSION is not compatible with this version of BibleTime.", name().latin1());
+		return false;
+	}
+
+	//then check if the index is there
+	return IndexReader::indexExists(getModuleStandardIndexLocation().ascii());
+}
+
+
+void CSwordModuleInfo::buildIndex() {
+	wchar_t wcharBuffer[LUCENE_MAX_FIELD_LENGTH + 1];
+
+	//Without this we don't get strongs, lemmas, etc
+	backend()->setFilterOptions ( CBTConfig::getFilterOptionDefaults() );
+	//make sure we reset all important filter options which influcence the plain filters.
+	backend()->setOption( CSwordModuleInfo::strongNumbers,  false );
+	backend()->setOption( CSwordModuleInfo::morphTags,  false );
+	backend()->setOption( CSwordModuleInfo::morphSegmentation,  false );
+	backend()->setOption( CSwordModuleInfo::footnotes,  false );
+	backend()->setOption( CSwordModuleInfo::headings,  false );
+	backend()->setOption( CSwordModuleInfo::scriptureReferences,  false );
+	backend()->setOption( CSwordModuleInfo::redLetterWords,  false );
+
+	lucene::analysis::standard::StandardAnalyzer an;
+	QString index = getModuleStandardIndexLocation();
+
+	QDir dir;
+	dir.mkdir( getGlobalBaseIndexLocation(), true );
+	dir.mkdir( getModuleBaseIndexLocation(), true );
+	dir.mkdir( getModuleStandardIndexLocation(), true );
+
+	
+	if (IndexReader::indexExists(index.ascii())){
+		if (IndexReader::isLocked(index.ascii()) ){
+			IndexReader::unlock(index.ascii());
+		}
+	}
+	
+	util::scoped_ptr<IndexWriter> writer( new IndexWriter(index.ascii(), &an, true) ); //always create a new index
+	writer->setMaxFieldLength(LUCENE_MAX_FIELD_LENGTH);
+	writer->setUseCompoundFile(true); //merge segments into a single file
+	writer->setMinMergeDocs(1000);
+	
+	long verseIndex, verseLowIndex, verseHighIndex = 1;
+	*m_module = sword::TOP;
+	verseLowIndex = m_module->Index();
+	*m_module = sword::BOTTOM;
+	verseHighIndex = m_module->Index();
+
+	const bool isVerseModule = (type() == CSwordModuleInfo::Bible) || (type() == CSwordModuleInfo::Commentary);
+	
+	m_indexingProgress.setValue( QVariant((int)0) );
+
+	QString key;
+	for (*m_module = sword::TOP; !m_module->Error(); (*m_module)++) {
+		Document* doc = new Document();
+		
+		// index the key
+		// we have to be sure to insert the english key into the index, otherwise we'd be in trouble if the
+		//language changes
+		key = QString::fromUtf8(m_module->getKey()->getText());
+		if (isVerseModule) {
+			VerseKey vk( m_module->getKey()->getText() );
+			vk.setLocale("en_US");
+			key = QString::fromUtf8(vk.getText());
+		}
+		//qWarning("key is %s", key.latin1());
+		lucene_utf8towcs(wcharBuffer, (const char*)key.utf8(), LUCENE_MAX_FIELD_LENGTH);
+		doc->add(*Field::UnIndexed(_T("key"), wcharBuffer));
+
+		// index the main text
+		//at this point we have to make sure we disabled the strongs and the other options
+		//so the plain filters won't include the numbers somehow.
+		lucene_utf8towcs(wcharBuffer, m_module->StripText(), LUCENE_MAX_FIELD_LENGTH);
+		doc->add(*Field::UnStored(_T("content"), wcharBuffer));
+
+		// index attributes
+		AttributeList::iterator attListI;
+		AttributeValue::iterator attValueI;
+		// Footnotes
+		for (attListI = m_module->getEntryAttributes()["Footnote"].begin();
+			attListI != m_module->getEntryAttributes()["Footnote"].end();
+			attListI++) {
+				lucene_utf8towcs(wcharBuffer, attListI->second["body"], LUCENE_MAX_FIELD_LENGTH);
+				doc->add(*Field::UnStored(_T("footnote"), wcharBuffer));
+		} // for attListI
+		
+		// Headings
+		for (attValueI = m_module->getEntryAttributes()["Heading"]["Preverse"].begin();
+			attValueI != m_module->getEntryAttributes()["Heading"]["Preverse"].end();
+			attValueI++) {
+			lucene_utf8towcs(wcharBuffer, attValueI->second, LUCENE_MAX_FIELD_LENGTH);
+			doc->add(*Field::UnStored(_T("heading"), wcharBuffer));
+		} // for attValueI
+
+		// Strongs/Morphs
+		for (attListI = m_module->getEntryAttributes()["Word"].begin();
+			attListI != m_module->getEntryAttributes()["Word"].end();
+			attListI++) {
+			// for each attribute
+			if (attListI->second["LemmaClass"] == "strong") {
+				lucene_utf8towcs(wcharBuffer, attListI->second["Lemma"], LUCENE_MAX_FIELD_LENGTH);
+				doc->add(*Field::UnStored(_T("strong"), wcharBuffer));
+				//qWarning("Adding strong %s", attListI->second["Lemma"].c_str());
+			}
+			if (attListI->second.find("Morph") != attListI->second.end()) {
+				lucene_utf8towcs(wcharBuffer, attListI->second["Morph"], LUCENE_MAX_FIELD_LENGTH);
+				doc->add(*Field::UnStored(_T("morph"), wcharBuffer));
+			}
+		} // for attListI
+		
+		writer->addDocument(doc);
+		delete doc;
+		verseIndex = m_module->Index();
+
+		if (verseIndex % 200 == 0){
+			if (verseHighIndex == verseLowIndex) { //prevent division by zero
+				m_indexingProgress.setValue( QVariant(0) );
+			}
+			else {
+				m_indexingProgress.setValue( QVariant((int)((100*(verseIndex-verseLowIndex))/(verseHighIndex-verseLowIndex))) );
+			}
+			
+			m_indexingProgress.activate();
+		}
+	}
+
+	writer->optimize();
+	writer->close();
+
+	QString configFilename = getModuleStandardIndexLocation() + QString("/../bibletime-index.conf");
+	util::scoped_ptr<KConfig> indexconfig( new KConfig( configFilename ) );
+	if (hasVersion()){
+		indexconfig->writeEntry("module-version", config(CSwordModuleInfo::ModuleVersion) );
+	}
+	indexconfig->writeEntry("index-version", INDEX_VERSION);
+
+}
+
+void CSwordModuleInfo::deleteIndexForModule( QString name ) {
+	util::filesystem::DirectoryUtil::removeRecursive( getGlobalBaseIndexLocation() + "/" + name );
+}
+
+unsigned long CSwordModuleInfo::indexSize() const {
+	return util::filesystem::DirectoryUtil::getDirSizeRecursive( getModuleBaseIndexLocation() );
+}
+
+
+const bool CSwordModuleInfo::searchIndexed(const QString& searchedText, sword::ListKey& scope)
+{
+	char utfBuffer[LUCENE_MAX_FIELD_LENGTH  + 1];
+	wchar_t wcharBuffer[LUCENE_MAX_FIELD_LENGTH + 1];
+		
+	// work around Swords thread insafety for Bibles and Commentaries
 	util::scoped_ptr < CSwordKey > key(CSwordKey::createInstance(this));
 	sword::SWKey* s = dynamic_cast < sword::SWKey * >(key.get());
+	QPtrList<VerseKey> list;
+	list.setAutoDelete( true ); // the list owns the objects
 
+	const bool isVerseModule = (type() == CSwordModuleInfo::Bible) || (type() == CSwordModuleInfo::Commentary);
+	
 	if (s) {
 		m_module->SetKey(*s);
 	}
 
-	//setup variables required for Sword
-	if (searchOptions & CSwordModuleSearch::caseSensitive) {
-		searchFlags = 0;
-	}
+	m_searchResult.ClearList();
+	
+	try {
+		standard::StandardAnalyzer analyzer;
+		IndexSearcher searcher(getModuleStandardIndexLocation().ascii());
+		lucene_utf8towcs(wcharBuffer, searchedText.utf8(), LUCENE_MAX_FIELD_LENGTH);
+		util::scoped_ptr<Query> q( QueryParser::parse(wcharBuffer, _T("content"), &analyzer) );
 
-	if (searchOptions & CSwordModuleSearch::cluceneIndex) {
-		searchType = -4;  //clucene search
-	}
-	else if (searchOptions & CSwordModuleSearch::entryAttribs) {
-		searchType = -3;  //Entry attributes
-	}
-	else if (searchOptions & CSwordModuleSearch::multipleWords) {
-		searchType = -2;  //multiple words
+		util::scoped_ptr<Hits> h( searcher.search(q, Sort::INDEXORDER) );
+		
+		const bool useScope = (scope.Count() > 0);
+//		const bool isVerseModule = (type() == CSwordModuleInfo::Bible) || (type() == CSwordModuleInfo::Commentary);
+		
+		Document* doc = 0;
+		util::scoped_ptr<SWKey> swKey( module()->CreateKey() );
 
-		if (m_module->hasSearchFramework()
-				&& m_module->isSearchOptimallySupported((const char *)searchedText.utf8(), -4, 0, 0)) {
-			searchType = -4;
+
+		for (int i = 0; i < h->length(); ++i) {
+			doc = &h->doc(i);
+			lucene_wcstoutf8(utfBuffer, doc->get(_T("key")), LUCENE_MAX_FIELD_LENGTH);
+			
+			swKey->setText(utfBuffer);
+			
+			// limit results based on scope
+			//if (searchOptions & CSwordModuleSearch::useScope && scope.Count() > 0){
+			if (useScope) {
+				for (int j = 0; j < scope.Count(); j++) {
+					VerseKey* vkey = dynamic_cast<VerseKey*>(scope.getElement(j));
+					if (vkey->LowerBound().compare(*swKey) <= 0 && vkey->UpperBound().compare(*swKey) >= 0){
+						m_searchResult.add(*swKey);
+					}
+				}
+			}
+			else { // no scope, give me all buffers
+				m_searchResult.add(*swKey);
+			}
 		}
 	}
-	else if (searchOptions & CSwordModuleSearch::exactPhrase) {
-		searchType = -1;  //exact phrase
+	catch (...) {
+		qWarning("CLucene exception");
+		return false;
 	}
-	else if (searchOptions & CSwordModuleSearch::regExp) {
-		searchType = 0;   //regexp matching
-	}
-
-	// 	if (!percentUpdate) {
-	// 		percentUpdate =
-	// 	}
-
-	if ((searchOptions & CSwordModuleSearch::useLastResult) && m_searchResult.Count()) {
-		util::scoped_ptr < sword::SWKey > searchScope(m_searchResult.clone());
-		m_searchResult = m_module->search(searchedText.utf8(), searchType, searchFlags, searchScope, 0, percentUpdate);
-	}
-	else if (searchOptions & CSwordModuleSearch::useScope) {
-		m_searchResult =
-			m_module->search(searchedText.utf8(), searchType, searchFlags,
-							 (type() != Lexicon && type() != GenericBook) ? &scope : 0, 0, percentUpdate);
-	}
-	else {
-		m_searchResult = m_module->search(searchedText.utf8(), searchType, searchFlags, 0, 0, percentUpdate);
-	}
-
+	
+	list.clear();
+	
 	return (m_searchResult.Count() > 0);
 }
 
+void CSwordModuleInfo::connectIndexingFinished(QObject* receiver, const char* slot) {
+	m_indexingFinished.connect(receiver, slot);
+}
+
+void CSwordModuleInfo::connectIndexingProgress(QObject* receiver, const char* slot) {
+	m_indexingProgress.connect(receiver, slot);
+}
+
+void CSwordModuleInfo::disconnectIndexingSignals(QObject* receiver) {
+	m_indexingProgress.disconnect(receiver);
+	m_indexingFinished.disconnect(receiver);
+}
+
 /** Returns the last search result for this module. */
 sword::ListKey & CSwordModuleInfo::searchResult(const sword::ListKey * newResult) {
 	if (newResult) {
@@ -186,11 +454,6 @@ void CSwordModuleInfo::clearSearchResult() {
 	m_searchResult.ClearList();
 }
 
-/** This interupts the search if this module is being searched. */
-void CSwordModuleInfo::interruptSearch() {
-	m_module->terminateSearch = true;
-}
-
 /** Returns the required Sword version for this module. Returns -1 if no special Sword version is required. */
 const sword::SWVersion CSwordModuleInfo::minimumSwordVersion() {
 	return sword::SWVersion(config(CSwordModuleInfo::MinimumSwordVersion).latin1());
@@ -330,8 +593,8 @@ const QString CSwordModuleInfo::config(const CSwordModuleInfo::ConfigEntry entry
 const bool CSwordModuleInfo::has(const CSwordModuleInfo::Feature feature) const {
 	switch (feature) {
 
-	case StrongsNumbers:
-	return m_module->getConfig().has("Feature", "StrongsNumber");
+// 		case StrongsNumbers:
+// 		return m_module->getConfig().has("Feature", "StrongsNumber");
 
 		case GreekDef:
 		return m_module->getConfig().has("Feature", "GreekDef");
