@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 //own includes
 #include "bibletime.h"
@@ -52,6 +61,8 @@
 //Sword includes
 #include <versekey.h>
 
+using namespace Profile;
+
 /* An action which stores a user defined pointer to a widget.
  * @author Joachim Ansorg
  */
@@ -101,7 +112,7 @@ void BibleTime::slotSettingsChanged() {
 
 /** Opens the sword setup dialog of BibleTime. */
 void BibleTime::slotSwordSetupDialog() {
-	InstallationManager::CSwordSetupDialog *dlg = new InstallationManager::CSwordSetupDialog(this, "CSwordSetupDialog");
+	BookshelfManager::CSwordSetupDialog *dlg = new BookshelfManager::CSwordSetupDialog(this, "CSwordSetupDialog");
 	connect(dlg, SIGNAL(signalSwordSetupChanged()), SLOT(slotSwordSetupChanged()) );
 
 	dlg->exec();
@@ -318,8 +329,10 @@ void BibleTime::slotToggleToolbar() {
 	}
 }
 
-/** Shows or hides the groupmanager. */
+/** Shows or hides the groupmanager. 
+*/
 void BibleTime::slotToggleMainIndex() {
+	//we use the parent widget because the main index is enclosed in a layout which adds the label at the top
 	if (m_viewMainIndex_action->isChecked()) {
 		m_mainIndex->parentWidget()->show();
 	}
@@ -362,7 +375,7 @@ void BibleTime::slotSearchModules() {
 		};
 	};
 
-	CSearchDialog::openDialog(modules, QString::null);
+	Search::CSearchDialog::openDialog(modules, QString::null);
 }
 
 /* Search default Bible slot
@@ -376,7 +389,7 @@ void BibleTime::slotSearchDefaultBible() {
 		module.append(bible);
 	}
 
-	CSearchDialog::openDialog(module, QString::null);
+	Search::CSearchDialog::openDialog(module, QString::null);
 }
 
 void BibleTime::openOnlineHelp_Handbook() {
@@ -517,10 +530,6 @@ void BibleTime::toggleFullscreen() {
 	if (m_windowFullscreen_action->isChecked()) {
 		showFullScreen();
 	}
-	else if (isVisible()) {
-		showNormal();
-	}
-
 	m_mdi->triggerWindowUpdate();
 }
 
