@@ -11,9 +11,11 @@ void CDisplayTemplateMgr::init() {
  <style type=\"text/css\">\
  /* <![CDATA[ */\
 \
+#LANG_CSS#\
+\
 * { \
  /* To work around a KDE 3.2 bug / problem */\
- background-color:inherit;\
+ background-color:transparent;\
 }\
 \
 #content {\
@@ -38,25 +40,26 @@ a {\
  text-decoration:none;\
  font-weight:normal;\
  color: #7B7B7B;\
- padding:2px;\
+ padding:0 2px;\
+ background-color:transparent;\
 }\
 a:hover {\
  text-decoration:none;\
  background-color:transparent;\
  color: #0000FF;\
- padding:2px;\
+ padding:0 2px;\
 }\
 \
 \
 /* Settings which apply to all entries in all modules */\
 .entry {\
- padding: 4px;\
-/* vertical-align: middle; */\
+ padding: 2px;\
+ vertical-align: middle;\
  text-align: justify;\
 /* line-height: 1.5em; */\
 }\
 td.entry {\
-/* padding: 4px; */\
+/* padding: 2px; */\
  vertical-align: top;\
  text-align: justify !important;\
 /* line-height: 1.5em; */\
@@ -74,8 +77,8 @@ td.entry {\
 \
 /* Keep the values the same as in .entry (take the border into account!) */\
 .currententry {\
- padding: 4px;\
-/* vertical-align: middle; */\
+ padding: 2px;\
+ vertical-align: middle;\
  text-align: justify;\
  background-color: #E6E4FF;\
 /* line-height: 1.5em; */\
@@ -87,7 +90,7 @@ div.currententry {\
 /* vertical-align:middle; */\
 }\
 span.currententry {\
- background-color: #EDEFFF;\
+ background-color: #EDEFFF !important;\
 }\
 \
 \
@@ -99,7 +102,7 @@ td.entry + td.entry { \
 /* Several additional settings for display of modules*/\
 #bible div.currententry, #bible td.currententry {\
  border: 1px solid #B7B7B7;\
- padding: 3px;\
+ padding: 2px;\
 /* vertical-align: middle; */\
 }\
 \
@@ -107,7 +110,7 @@ td.entry + td.entry { \
 /*Same for books!*/\
 #book div.currententry, #book td.currententry {\
  border: 1px solid #B7B7B7;\
- padding: 3px;\
+ padding: 2px;\
 }\
 #book .entryname + .entry {\
  margin-top:2px;\
@@ -120,18 +123,18 @@ td.entry + td.entry { \
 }\
 \
 .entryname {\
- font-size:70%;\
+ font-size:80%;\
  padding:0 2px 0 0;\
- vertical-align:top;\
+ vertical-align:super;\
 }\
 .entry[dir=rtl] .entryname, .currententry[dir=rtl] .entryname {\
  padding: 0 0 0 2px;\
- font-size: 70%;\
- vertical-align: top;\
+ font-size: 80%;\
+ vertical-align: super;\
 }\
 .entryname a, #printer .entryname {\
 /* vertical-align: middle */\
- font-size: 80%;\
+ /*font-size: 80% !important;*/\
 }\
 \
 #printer .entry .entry, #printer .entry .sectiontitle , #printer .entry .booktitle {\
@@ -140,14 +143,15 @@ td.entry + td.entry { \
 }\
 \
 .footnote {\
- vertical-align: top;\
+ vertical-align:super;\
  font-weight: normal;\
  color: blue;\
  font-size: 80%;\
  cursor: help;\
+ background-color:transparent;\
 }\
-.footnote:before { content:\"(\"; font-size:60%; cursor:help;}\
-.footnote:after { content:\")\"; font-size:60%; cursor:help;}\
+.footnote:before { content:\"(\"; }\
+.footnote:after { content:\")\"; }\
 \
 .footnotepre {\
 /* vertical-align: middle; */\
@@ -158,10 +162,10 @@ td.entry + td.entry { \
 .crossreference {\
  font-size: 80%;\
  color: blue;\
-/* cursor: help; */\
 }\
 #bible .crossreference:before { content:\" [\"; }\
 #bible .crossreference:after { content:\"]\"; }\
+\
 .crossreference a {\
  color: blue;\
 }\
@@ -281,9 +285,9 @@ td.entry + td.entry { \
 \
 .morphSegmentation {\
  border-right: 2px solid grey;\
-/* margin-top: 1px; /* Don`t let the boxes touch here, between the lines */ */\
+/* margin-top: 1px; /* Don`t let the boxes touch here, between the lines */\
 /* margin-left: -1px; /* But here, for better reading of the text, */\
-/* this will only occur within a word consisting of several segments.*/ */\
+/* this will only occur within a word consisting of several segments.*/\
 /* margin-right: 0px; */\
 }\
 \
@@ -348,7 +352,6 @@ td.entry + td.entry { \
  color:black;\
 }\
 \
-#LANG_CSS#\
  /* ]]> */\
  </style>\
 </head>\
@@ -362,6 +365,7 @@ td.entry + td.entry { \
 <!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\
 <html xmlns=\"http://www.w3.org/1999/xhtml\">\
 <head>\
+ <!--TODO: This needs a better title than \"Crazy\"-->\
  <title>#TITLE#</title>\
  <meta name=\"GENERATOR\" content=\"BibleTime - www.bibletime.info\" />\
  <meta name=\"AUTHOR\" content=\"BibleTime - www.bibletime.info\" />\
@@ -374,10 +378,11 @@ body {\
  margin:0px;\
  padding:0;\
  padding:1em;\
- background-color:inherit\
+ background-color:transparent;\
 }\
+\
 * {\
- background-color:inherit; /* To work around a KDE 3.2 bug / problem */\
+ background-color:transparent; /* To work around a KDE 3.2 bug / problem */\
 }\
 \
 \
@@ -386,7 +391,6 @@ body {\
  margin:0px;\
  padding:0px;\
  font-size:12pt;\
- line-height:1.2em;\
  text-align:justify;\
 }\
 \
@@ -396,6 +400,7 @@ body {\
  padding:3px;\
  border-spacing:0;\
  vertical-align:top;\
+ text-align:justify;\
 }\
 /* The heading contains the name of the module and may contain additional information like the display keys */\
 #content > table th {\
@@ -411,10 +416,12 @@ body {\
 \
 #content tr:nth-child(even) { background-color: #EDEDED; }\
 #content div.entry:nth-child(even) { background-color: #EDEDED; }\
+/*#content tr:nth-child(even) { background-color: #D0D0D0; }\
+#content div.entry:nth-child(even) { background-color: #D0D0D0; }*/\
 \
 \
 /* The a links are the normal HTML hyperlinks. Links without a class attribute are hyperlinks into the web */\
-a { color:#FF0004; }\
+a { color:#FF0004; padding:0; }\
 a:hover { }\
 \
 /* An entry is the generic element used for all content items.\
@@ -427,12 +434,15 @@ a:hover { }\
  */\
 .entry {\
  padding:0.3em;\
- line-height:1.6em;\
 }\
-table .entry:nth-child(1) {\
+table .entry:nth-child(odd) {\
  border-left:10px solid #DEE6F6;\
 }\
 \
+table .entry:nth-child(even) {\
+ border-left:10px solid #E6EEFF;\
+}\
+\
 #printer .entry { text-indent:15px; }\
 /* Often needed to format BiDi text in the right way */\
 /* .entry[dir=rtl] { text-align:right !important; } */b\
@@ -449,12 +459,16 @@ td.entry {\
  */\
 .currententry {\
  padding:0.3em;\
- /*line-height:1.6em;*/\
+ line-height:1.6em;\
  background-color:#D3E5FF;\
+ /*border: thin solid black;*/\
+ \
 }\
+\
 table .currententry:nth-child(1) {\
  margin-left:0;\
  border-left:10px solid #99B4FF;\
+ /*border-left:10px solid #F5FF6A;*/\
 }\
 /* .currententry[dir=rtl] { */\
 /* } */\
@@ -492,8 +506,8 @@ td.entry + td.entry {\
 #book .entry > *, #book .currententry > * { }\
 \
 /* An entryname is embedded in an .entry tag and contains the name of the key, which belongs to the text of the .entry */\
-.entryname { size:60%; vertical-align:super; }\
-.entryname a {text-decoration:none !important; color:#8F2627 !important; font-style:italic; }\
+.entryname { size:60%; vertical-align:super;}\
+.entryname a { text-decoration:none !important; color:#8F2627 !important; font-style:italic; padding:0; }\
 \
 .entry[dir=rtl] .entryname, .currententry[dir=rtl] .entryname { }\
 .entryname a, #printer .entryname { }\
@@ -502,15 +516,28 @@ td.entry + td.entry {\
 \
 /* Footnote formatting options */\
 /* A footnote is displayed as an asterisk or another small character. You can set the colors, font-size, etc. for the footnote. */\
-.footnote { color:#8F2627; vertical-align:super; font-size:60%;}\
+.footnote { color:#8F2627; vertical-align:super; font-size:70%;}\
 /* You may use this to add sourrounding brackets in Bible modules. To do this the content command of CSS */\
-#bible .footnote:before { content:\"[\"; color:#8F2627; vertical-align:super; font-size:60%;}\
-#bible .footnote:after { content:\"]\"; color:#8F2627; vertical-align:super; font-size:60%;}\
+#bible .footnote:before { content:\" [\"; color:#8F2627; }\
+#bible .footnote:after { content:\"]\"; color:#8F2627; }\
 \
 /* Crossreferences. The same as footnotes */\
-.crossreference { color:#8F2627;}\
-#bible .crossreference:before { }\
-#bible .crossreference:after { }\
+.crossreference { color:#8f2627;}\
+#bible .crossreference:before { content:\" {\" }\
+#bible .crossreference:after { content:\"}\" }\
+\
+/*Keep in mind that for cross references it is not enough to\
+*set only the cross reference colour, you must also set the\
+*cross reference anchor marker with .crossreference a\
+*This way both the non linked and linked text will show\
+*as desired. Additionally, you can have seperate formatting\
+*for linked and non linked text in the cross reference*/\
+.crossreference a {\
+ color:#8f2627;\
+ /*Get rid of underlines on the notes when not hovered*/\
+ text-decoration: none;\
+}\
+.crossreference a:hover {}\
 \
 /* Alternative reading as defined in the OSIS specs. The information about the alternative text is displayed in the info display. It's\
 often a good idea to format this the same as footnotes\
@@ -527,7 +554,7 @@ so something like .alternative:before { content:\"'\"attr(alternative); } is pos
 /* A title within the text. This is the formatting which applies to a title of a section, as you can find them in Bibles */\
 .sectiontitle {\
  padding:0.3em;\
- text-shadow:gray 0px 0px 3px;\
+ /*text-shadow:gray 0px 0px 3px;*/\
  font-size:1.3em;\
  font-weight:bold;\
  text-transform:uppercase;\
@@ -545,7 +572,8 @@ so something like .alternative:before { content:\"'\"attr(alternative); } is pos
 .foreign { }\
 \
 /* Words spoken by Jesus Christ */\
-.jesuswords { color: red; }\
+/*.jesuswords { color: red; }*/\
+.jesuswords { color: #B60000; }\
 \
 /* An introduction to a module, book or chapter */\
 .introduction { }\
@@ -563,9 +591,13 @@ so something like .alternative:before { content:\"'\"attr(alternative); } is pos
 .center { }\
 \
 /* Visual attributes to the text */\
-.bold { }\
+.bold {\
+ font-weight: bold;\
+}\
 .illuminated { }\
-.italic { }\
+.italic {\
+ font-style: italic;\
+}\
 .line-through { }\
 .normal { }\
 .small-caps{ }\
@@ -669,7 +701,7 @@ so something like .alternative:before { content:\"'\"attr(alternative); } is pos
 \
 * { \
  /* To work around a KDE 3.2 bug / problem */\
- background-color:inherit;\
+ background-color:transparent;\
 }\
 \
 #content {\
@@ -694,18 +726,19 @@ a {\
  text-decoration:none;\
  font-weight:normal;\
  color: #3B11AE;\
- padding:2px;\
+ background-color:transparent; \
+ padding:0 2px;\
 }\
 a:hover {\
- background-color:#F6FFF7;\
+ background-color:transparent;\
  color: #AE1518;\
- padding:2px;\
+ padding:0 2px;\
 }\
 \
 \
 /* Settings which apply to all entries in all modules */\
 .entry {\
- padding: 4px;\
+ padding: 3px;\
  vertical-align: middle;\
  text-align: justify;\
 }\
@@ -720,12 +753,12 @@ a:hover {\
  text-align:right !important;\
 }\
 div.entry, td.entry {\
- vertical-align:top; \
+ vertical-align:top;\
 }\
 \
 /* Keep the values the same as in .entry (take the border into account!) */\
 .currententry {\
- padding:4px;\
+ padding:3px;\
  vertical-align:middle;\
  text-align:justify;\
 }\
@@ -747,7 +780,7 @@ td.entry + td.entry { \
 /* Several additional settings for display of modules*/\
 #bible div.currententry, #bible td.currententry {\
  border:1px solid black;\
- padding: 4px;\
+ padding:2px;\
  background-color:#F6FFF7;\
 }\
 #bible span.currententry {\
@@ -765,18 +798,17 @@ td.entry + td.entry { \
 \
 \
 .entryname {\
- font-size:70%;\
+ font-size:80%;\
  padding:0 2px 0 0;\
- vertical-align:top;\
+ vertical-align:super;\
 }\
 .entry[dir=rtl] .entryname, .currententry[dir=rtl] .entryname {\
  padding: 0 0 0 2px;\
- font-size: 70%;\
- vertical-align: top;\
+ font-size: 80%;\
+ vertical-align:super;\
 }\
 .entryname a, #printer .entryname {\
  vertical-align: middle\
- font-size: 80%;\
 }\
 \
 #printer .entry .entry, #printer .entry .sectiontitle , #printer .entry .booktitle {\
@@ -785,16 +817,32 @@ td.entry + td.entry { \
 }\
 \
 .footnote {\
- vertical-align: top;\
+ vertical-align:super;\
  color: blue;\
  font-size: 70%;\
 }\
+.footnote:before { content:\"(\"; }\
+.footnote:after { content:\")\"; }\
+\
 .crossreference {\
  font-size: 80%;\
  /*vertical-align:middle;*/\
  color: blue;\
 }\
 \
+.crossreference a {\
+ font-size: 80%;\
+ /*vertical-align:middle;*/\
+ color: blue;\
+}\
+\
+.crossreference a:hover {\
+ font-size: 80%;\
+ /*vertical-align:middle;*/\
+ color: blue;\
+}\
+\
+\
 \
 .sectiontitle {\
  font-weight: bold;\
@@ -980,11 +1028,11 @@ td.entry + td.entry { \
 \
 * { \
  /* To work around a KDE 3.2 bug / problem */\
- background-color:inherit;\
+ background-color:transparent;\
 }\
 \
 #content {\
- background-color:white;\
+ /*background-color:white;*/\
  margin:10px;\
 }\
 #content > table {\
@@ -996,7 +1044,7 @@ td.entry + td.entry { \
 #content > table th {\
  padding: 0 0 2px 0;\
  text-align: center; \
- font-weight: bold;\
+ /*font-weight: bold;*/\
  font-size: 110%;\
  border-bottom: 1px solid #6B6B6B;\
 }\
@@ -1004,13 +1052,12 @@ td.entry + td.entry { \
 a {\
  text-decoration:none;\
  font-weight:normal;\
- /*color: #0000FF;*/\
- color: #F98100;\
- color:inherit;\
+ /*color: #F98100;*/\
  padding:1px;\
+ background-color:transparent;\
 }\
 a:hover {\
- background-color:#F6FFF7;\
+ background-color:transparent;\
  color: #FF0000;\
  padding:1px;\
  text-decoration:underline;\
@@ -1040,8 +1087,10 @@ div.entry, td.entry {\
  text-align: justify;\
  /*font-weight: bolder;*/\
  /*background-color:transparent;*/\
- color:white;\
- background-color:black;\
+ /*color:white;*/\
+ /*background-color:black;*/\
+ /*The background colour of selected text as of kde 3.5.2*/\
+ background-color: #A5A5FF;\
 }\
 .currententry[dir=rtl] {\
  text-align: right;\
@@ -1060,7 +1109,7 @@ td.entry + td.entry { \
 \
 /* Several additional settings for display of modules*/\
 #bible div.currententry, #bible td.currententry {\
- border: 1px solid black;\
+ /*border: 1px solid black;*/\
  padding: 4px;\
 }\
 #bible span.currententry {\
@@ -1075,10 +1124,12 @@ td.entry + td.entry { \
 \
 \
 .entryname {\
- font-size:80%;\
+ font-size:70%;\
  padding:0 1px 0 0;\
- /*vertical-align:top;*/\
- color: #F98100;\
+ vertical-align:top;\
+ /*color: #F98100;*/\
+ color: black;\
+ /*font-style: italic;*/\
 }\
 .entry[dir=rtl] .entryname, .currententry[dir=rtl] .entryname {\
  padding:0 0 0 1px;\
@@ -1088,6 +1139,8 @@ td.entry + td.entry { \
 .entryname a, #printer .entryname {\
  vertical-align: top;\
  font-size: 100%;\
+ font-weight: bold;\
+ color: black;\
 }\
 \
 #printer .entry .entry, #printer .entry .sectiontitle , #printer .entry .booktitle {\
@@ -1095,25 +1148,38 @@ td.entry + td.entry { \
  margin-left:10px;\
 }\
 \
-.footnotepre {\
- color: gray;\
- font-size: 0.9em;\
- font-style: italic;\
-}\
 .footnote {\
- vertical-align:top;\
+ vertical-align:super;\
  font-weight:bold;\
- /*color:black;*/\
- /*color:blue;*/\
  /*color: #00B7FF;*/ /*This one is kind of blinding on white*/\
- color: #F98100;\
+ /*color: #F98100;*/\
  font-size:80%;\
+ color: black;\
+ content: \"1\";\
 }\
+\
+\
+.footnote:before {\
+ content: \"(\";\
+}\
+\
+.footnote:after {\
+ content: \")\";\
+}\
+\
 .crossreference {\
  font-size: 80%;\
  /*vertical-align:middle;*/\
  /*color: blue;*/\
- color: #F98100;\
+ /*color: #F98100;*/\
+}\
+\
+.crossreference:before {\
+ content: \"[\";\
+}\
+\
+.crosreference:after {\
+ content: \"]\";\
 }\
 \
 .sectiontitle {\
@@ -1143,9 +1209,9 @@ td.entry + td.entry { \
 .jesuswords {\
  /*color:red;*/\
  /*color: #7500AC;*/\
- color: #F98100;\
- /*font-style:italic;*/\
- font-weight: bold;\
+ /*color: #F98100;*/\
+ font-style:italic;\
+ /*font-weight: bold;*/\
  font-size:0.9em;\
 }\
 \
@@ -1262,7 +1328,7 @@ td.entry + td.entry { \
  padding: 2px;\
  margin: 0px;\
  text-align: left;\
- font-weight: bold; \
+ font-weight: bold;\
  font-size: 90%;\
 }\
 \
@@ -1348,9 +1414,6 @@ span.currententry {\
  padding: 5px;\
 }\
 \
-.footnotepre {\
- color: gray;\
-}\
 .footnote {\
  color: gray;\
 }\
@@ -1404,8 +1467,14 @@ span.currententry {\
 .center {\
  text-align: center;\
 }\
-\
-\
+/*TODO: Think of something better here since this will get confusing*/\
+/* on verses but, is needed for things inthe Mag/Info window*/\
+.bold {\
+ font-weight: bold;\
+}\
+.italic {\
+ font-style: italic;\
+}\
 #LANG_CSS#\
 /* ]]> */\
  </style>\
