@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #ifndef BTINSTALLMGR_H
 #define BTINSTALLMGR_H
@@ -18,7 +27,7 @@
 #include <qstring.h>
 #include <qstringlist.h>
 
-namespace InstallationManager {
+namespace BookshelfManager {
 
 	typedef QPtrList<sword::InstallSource> InstallSourceList;
 
