@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #ifndef CPLAINWRITEDISPLAY_H
 #define CPLAINWRITEDISPLAY_H
@@ -35,7 +44,7 @@ public:
 	*/
 	virtual QWidget* view();
 	virtual const QString text( const CDisplay::TextType format = CDisplay::HTMLText, const CDisplay::TextPart part = CDisplay::Document );
-	virtual void print( const CDisplay::TextPart );
+	virtual void print( const CDisplay::TextPart, CSwordBackend::DisplayOptions displayOptions, CSwordBackend::FilterOptions filterOptions );
 	/**
 	* Reimplementation.
 	*/
