@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 //BibleTime includes
 #include "creadwindow.h"
@@ -13,6 +22,7 @@
 #include "frontend/cprofilewindow.h"
 #include "frontend/displaywindow/cmodulechooserbar.h"
 #include "frontend/keychooser/ckeychooser.h"
+#include "frontend/searchdialog/csearchdialog.h"
 
 #include "util/cresmgr.h"
 
@@ -23,6 +33,8 @@
 #include <kstdaccel.h>
 #include <klocale.h>
 
+using namespace Profile;
+
 CReadWindow::CReadWindow(ListCSwordModuleInfo modules, CMDIArea* parent, const char *name )
 : CDisplayWindow(modules,parent,name),
 m_displayWidget(0) {
@@ -166,8 +178,18 @@ void CReadWindow::copyDisplayedText() {
     \fn CReadWindow::resizeEvent(QResizeEvent* e)
  */
 void CReadWindow::resizeEvent(QResizeEvent* /*e*/) {
-	//  qWarning("resizeEvent...");
 	displayWidget()->moveToAnchor(
 		Rendering::CDisplayRendering::keyToHTMLAnchor(key()->key())
 	);
 }
+
+void CReadWindow::openSearchStrongsDialog() {
+//	qWarning("looking for lemma %s",  displayWidget()->getCurrentNodeInfo()[CDisplay::Lemma].latin1() );
+	QString searchText = QString::null;
+	
+	if (displayWidget()->getCurrentNodeInfo()[CDisplay::Lemma] != QString::null) {
+		searchText.append("strong:").append(displayWidget()->getCurrentNodeInfo() [CDisplay::Lemma]);
+	}
+	
+	Search::CSearchDialog::openDialog( modules(), searchText, 0 );
+}
