@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 //BibleTime includes
 #include "cmainindex.h"
@@ -15,6 +24,7 @@
 #include "frontend/cprinter.h"
 
 #include "util/cresmgr.h"
+#include "util/scoped_resource.h"
 
 //Qt includes
 #include <qheader.h>
@@ -146,6 +156,7 @@ void CMainIndex::initView() {
 	m_actions.deleteEntries = new KAction(i18n("Remove selected item(s)"),CResMgr::mainIndex::deleteItems::icon, 0, this, SLOT(deleteEntries()), this);
 
 	m_actions.editModuleMenu = new KActionMenu(i18n("Edit this work"),CResMgr::mainIndex::editModuleMenu::icon, this);
+	m_actions.editModuleMenu->setDelayed(false);
 	m_actions.editModulePlain = new KAction(i18n("Plain text"),CResMgr::mainIndex::editModulePlain::icon, 0, this, SLOT(editModulePlain()), this);
 	m_actions.editModuleHTML = new KAction(i18n("HTML"),CResMgr::mainIndex::editModuleHTML::icon, 0, this, SLOT(editModuleHTML()), this);
 
@@ -484,7 +495,8 @@ void CMainIndex::printBookmarks() {
 		}
 	}
 
-	CPointers::printer()->printKeyTree(tree);
+	util::scoped_ptr<CPrinter> printer( new CPrinter( this, CBTConfig::getDisplayOptionDefaults(), CBTConfig::getFilterOptionDefaults() ) );
+	printer->printKeyTree(tree);
 }
 
 /** Deletes the selected entries. */
@@ -526,7 +538,7 @@ void CMainIndex::searchInModules() {
 		}
 	}
 
-	CSearchDialog::openDialog(modules, QString::null);
+	Search::CSearchDialog::openDialog(modules, QString::null);
 }
 
 /** Unlocks the current module. */
@@ -534,14 +546,11 @@ void CMainIndex::unlockModule() {
 	if (CModuleItem* i = dynamic_cast<CModuleItem*>(currentItem())) {
 		bool ok;
 		QString unlockKey = QInputDialog::getText(i18n("BibleTime - Unlock work"),
-							i18n("Enter the unlock key for this work."),
-							QLineEdit::Normal, i->module()->config(CSwordModuleInfo::CipherKey),
-							&ok);
+			i18n("Enter the unlock key for this work."),
+			QLineEdit::Normal, i->module()->config(CSwordModuleInfo::CipherKey), &ok);
 		if (ok) {
-			/*const bool ret =*/ i->module()->unlock( unlockKey );
-			//    if ( !ret ) { // an error occured
-			//
-			//    }
+			i->module()->unlock( unlockKey );
+			emit signalSwordSetupChanged();
 		}
 	}
 }
