@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 //own includes
 #include "cresmgr.h"
@@ -389,6 +398,14 @@ namespace CResMgr {
 				const KShortcut accel     = Qt::ALT + Qt::Key_Right;
 				const char* actionName    = "window_history_forward_action";
 			}
+			namespace findStrongs {
+				QString tooltip;
+
+				const QString icon        = "bt_findstrongs";
+				const KShortcut accel     = KShortcut(0);
+				const char* actionName    = "window_find_strongs_action";
+			}
+
 		}
 		namespace bibleWindow {
 			namespace bookList {
@@ -406,7 +423,6 @@ namespace CResMgr {
 				const KShortcut accel = Qt::CTRL + Qt::SHIFT + Qt::Key_Y;
 			}
 
-
 			namespace chapterList {
 				QString tooltip;
 			}
@@ -976,6 +992,10 @@ The others are user defined search scopes.");
 						tooltip = i18n ("Go forward one item in the display history.") ;
 
 					}
+					{
+						using namespace findStrongs;
+						tooltip = i18n ("Show all occurences of the Strong number currently under the mouse cursor.") ;
+					}
 				}
 				using namespace bibleWindow;
 				{
